/*
Created		07/11/2006
Modified		11/07/2007
Project		Spagic
Model		Bck Database
Company		Engineering
Author		Spagic Team
Version		2.0.0
Database    Oracle 9i
*/

Create table process_instance (
	id_process_instance Integer NOT NULL ,
	id_parent_process_instance Integer,
	id_process Integer NOT NULL ,
	startdate Timestamp NOT NULL ,
	enddate Timestamp NOT NULL ,
	executiontime Integer,
	state Integer NOT NULL ,
	id_correlation Varchar2 (100) NOT NULL ,
	id_pool Integer,
	id_process_execution_state Integer Default 0 NOT NULL ,
primary key (id_process_instance) 
) 
;

Create table transition_instance (
	id_journal Integer NOT NULL ,
	id_step_source Integer,
	id_step_target Integer NOT NULL ,
	id_process_instance Integer NOT NULL ,
	id_message Varchar2 (100) NOT NULL ,
	transition_start Timestamp NOT NULL ,
	transition_end Timestamp,
	transition_execution_time Integer,
	id_ext_process_instance Integer,
	id_state Integer NOT NULL ,
	transition_data Clob,
	transition_data_out Clob,
	attachment_in Integer DEFAULT 0,
	attachment_out Integer DEFAULT 0,
	runtime_warning Char(1) DEFAULT 0,
primary key (id_journal) 
) 
;

Create table log_journal (
	id_log Integer NOT NULL ,
	id_state Integer NOT NULL ,
	id_journal Integer NOT NULL ,
	name Varchar2 (200),
	log Clob NOT NULL ,
	datelog Timestamp NOT NULL ,
primary key (id_log) 
) 
;

Create table relevant_data (
	id_relevant_data Integer NOT NULL ,
	id_attribute Integer NOT NULL ,
	id_log Integer NOT NULL ,
	value Varchar2 (500) NOT NULL ,
primary key (id_relevant_data) 
) 
;

Create table pool_instance (
	id_pool Integer NOT NULL ,
	id_pool_type Integer NOT NULL ,
	unique_pool_instance_key Varchar2 (1000) NOT NULL ,
primary key (id_pool) 
) 
;

Create table relevant_data_process_instance (
	id_process_instance Integer NOT NULL ,
	id_relevant_data Integer NOT NULL ,
primary key (id_process_instance,id_relevant_data) 
) 
;

CREATE VIEW main_relevant_data_process AS 
	SELECT r.id_process_instance, r.id_relevant_data, i.id_parent_process_instance
	FROM spagic.relevant_data_process_instance r, spagic.process_instance i
	WHERE r.id_process_instance = i.id_process_instance;

CREATE VIEW main_relevant_data AS 
	SELECT r.id_relevant_data, r.id_attribute, r.id_log, r.value, j.id_process_instance 
	FROM spagic.relevant_data r, spagic.log_journal l, spagic.transition_instance j, spagic.process_instance i 
	WHERE r.id_log=l.id_log 
	AND l.id_journal=j.id_journal 
	AND j.id_process_instance=i.id_process_instance; 

CREATE VIEW main_log_journal AS 
	SELECT l.id_log, l.id_state, l.id_journal, l.name, l.log, l.datelog, i.id_process_instance
	FROM spagic.log_journal l, spagic.transition_instance j, spagic.process_instance i 
	WHERE l.id_journal=j.id_journal 
	AND j.id_process_instance=i.id_process_instance;

CREATE VIEW main_transition_instance AS 
	SELECT j.id_journal, j.id_step_source, j.id_step_target, j.id_process_instance, j.id_message, j.transition_start, j.transition_end, j.id_ext_process_instance, j.id_state, j.transition_data 
	FROM  spagic.transition_instance j, spagic.process_instance i 
	WHERE j.id_process_instance=i.id_process_instance;

CREATE VIEW main_process_instance AS 
	SELECT i.id_process_instance, i.id_process, i.startdate, i.enddate, i.state, i.id_correlation, i.id_pool , id_parent_process_instance, id_process_execution_state
	FROM spagic.process_instance i;

CREATE VIEW main_pool_instance AS 
	SELECT i.id_pool, i.id_pool_type, i.unique_pool_instance_key 
	FROM spagic.pool_instance i;

CREATE VIEW main_temporary_process AS 
	SELECT id_process_instance FROM spagic.temporary_process_instance;
